@@ -1,14 +1,14 @@
 #<<<
 use strict; use warnings;
 #>>>
-#
+
 package Plack::Middleware::LogAny;
 
 use parent                qw( Plack::Middleware );
 use Log::Any              qw();
 use Plack::Util::Accessor qw( category logger );
 
-our $VERSION = '0.001001';
+our $VERSION = '0.001002';
 
 sub prepare_app {
   my ( $self ) = @_;
@@ -19,9 +19,9 @@ sub call {
   my ( $self, $env ) = @_;
 
   $env->{ 'psgix.logger' } = sub {
-    my $args  = shift;
-    my $level = $args->{ level };
-    $self->logger->$level( $args->{ message } );
+    my ( $level, $message ) = @{ $_[ 0 ] }{ qw( level message ) };
+
+    $self->logger->$level( $message );
   };
 
   $self->app->( $env );
